<?php

namespace Drupal\restrict_ip\Access;

use Drupal\Core\Config\ConfigFactoryInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\Core\DependencyInjection\ContainerInjectionInterface;

/**
 * An IP permissions helper class.
 */
class RestrictIpPermissions implements RestrictIpPermissionsInterface, ContainerInjectionInterface {

  /**
   * The Config Factory service.
   *
   * @var \Drupal\Core\Config\ConfigFactoryInterface
   */
  protected $configFactory;

  /**
   * Constructs the PageController object for the Restrict IP module.
   *
   * @param \Drupal\Core\Config\ConfigFactoryInterface $configFactory
   *   The Config Factory service.
   */
  public function __construct(ConfigFactoryInterface $configFactory) {
    $this->configFactory = $configFactory;
  }

  /**
   * {@inheritDoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('config.factory'),
    );
  }

  /**
   * {@inheritdoc}
   */
  public function permissions() {
    $permissions = [];

    if ($this->configFactory->get('restrict_ip.settings')->get('allow_role_bypass')) {
      $permissions['bypass ip restriction'] = [
        'title' => 'Bypass IP Restriction',
        'description' => 'Allows the user to access the site even if not in the IP whitelist',
      ];
    }

    return $permissions;
  }

}
